@@ -7,20 +7,21 @@ import threading
 import subprocess
 import pkg_resources
 
-from signal import signal, SIGPIPE, SIG_DFL 
-signal(SIGPIPE,SIG_DFL)
+# from signal import signal, SIGPIPE, SIG_DFL 
+# signal(SIGPIPE,SIG_DFL)
 
-METEOR_JAR = 'meteor-1.5.jar'
+METEOR_JAR = os.path.join(os.path.abspath(os.path.dirname(__file__)), 'meteor-1.5.jar')
 class Meteor(object):
     def __init__(self, language='en', norm=True):
+        print(METEOR_JAR)
         self.meteor_cmd = ['java', '-jar', '-Xmx2G', METEOR_JAR, '-', '-', '-stdio', '-l', language]
 
         if norm:
             self.meteor_cmd.append('-norm')
 
         self.meteor_p = subprocess.Popen(self.meteor_cmd, stdin=subprocess.PIPE,
-            cwd=os.path.dirname(os.path.abspath(__file__)), 
-                                        stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True, bufsize=1)
+                                            cwd=os.path.dirname(os.path.abspath(__file__)), 
+                                            stdout=subprocess.PIPE, stderr=subprocess.PIPE, universal_newlines=True, bufsize=1)
         # Used to guarantee thread safety
         self.lock = threading.Lock()
 
@@ -40,6 +41,7 @@ class Meteor(object):
             score_line = ' ||| '.join(('SCORE', ' ||| '.join(gts[i]), hypothesis_str))
 
             # We obtained --> SCORE ||| reference 1 words ||| reference n words ||| hypothesis words
+            print(self.meteor_p.poll())
             self.meteor_p.stdin.write(score_line + '\n')
             stat = self.meteor_p.stdout.readline().strip()
             eval_line += ' ||| {}'.format(stat)
