@@ -182,7 +182,7 @@ class DecoderRNNFB(BaseRNN):
             decoder_input = inputs[:, 0].unsqueeze(1)
             for di in range(max_length):                            
                 decoder_output, decoder_output_state, decoder_hidden, step_attn = \
-                    self.forward_step(decoder_input, pg_encoder_states, decoder_hidden,
+                    self._step(decoder_input, pg_encoder_states, decoder_hidden,
                                       encoder_outputs, function=function)
                 # # not allow decoder to output UNK
                 decoder_output[:, :, 3] = -float('inf')
