@@ -63,21 +63,21 @@ def train_epoches(dataset, model, criterion, optimizer,
         epoch_examples_total = 0
         epoch_loss_list = [0] * config.num_of_exams
         for batch_idx, (source, target, input_lengths) in enumerate(train_loader):
-            try:
-                input_variables = source
-                target_variables = target
-                # train model              
-                loss_list = train_batch(model, criterion, optimizer, vocab_size,
-                                            input_variables, input_lengths.tolist(),
-                                            target_variables, teacher_forcing_ratio,
-                                            config)
-                # Record average loss
-                num_examples = len(source)
-                epoch_examples_total += num_examples
-                for i in range(config.num_of_exams):
-                    epoch_loss_list[i] += loss_list[i] * num_examples
-            except:
-                continue
+            #try:
+            input_variables = source
+            target_variables = target
+            # train model              
+            loss_list = train_batch(model, criterion, optimizer, vocab_size,
+                                        input_variables, input_lengths.tolist(),
+                                        target_variables, teacher_forcing_ratio,
+                                        config)
+            # Record average loss
+            num_examples = len(source)
+            epoch_examples_total += num_examples
+            for i in range(config.num_of_exams):
+                epoch_loss_list[i] += loss_list[i] * num_examples
+            #except:
+            #    continue
 
         for i in range(config.num_of_exams):
             epoch_loss_list[i] /= float(epoch_examples_total)
