@@ -4,7 +4,7 @@ import os
 LOGGER_PRINT_LEVEL = logging.DEBUG
 DIRECTORY = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 DIRECTORY_DATA = os.path.join(DIRECTORY, 'data')
-DIRECTORY_OUTPUT = os.path.join(DIRECTORY, 'output')
+DIRECTORY_OUTPUT = os.path.join(DIRECTORY_DATA, 'output')
 
 class Config(object):
     seed = 1111
